/*
 * Copyright 2013 Zakhar Prykhoda
 *
 *    midao.org
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.midao.jdbc.core.handlers.output;

import org.midao.jdbc.core.exception.MidaoException;
import org.midao.jdbc.core.handlers.model.QueryParameters;

import java.util.List;

/**
 * Interface for all query output processors.
 * Those classes should convert query output into specific Java types
 */
public interface OutputHandler<T> {

    /**
     * Reads query output and converts it into <T>
     *
     * @param outputList Query output
     * @return Java type converted from query output
     * @throws MidaoException
     */
    T handle(List<QueryParameters> outputList) throws MidaoException;
}